==> qt-everywhere-opensource-src-5.2.0.tar.xz: qt-everywhere-opensource-src-5.2.0/qtsensors/src/plugins/sensors/sensorfw/sensorfwcompass.h <==
/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtSensors module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef SENSORFWCOMPASS_H
#define SENSORFWCOMPASS_H

#include "sensorfwsensorbase.h"
#include <QtSensors/qcompass.h>

#include <compasssensor_i.h>
#include <datatypes/compass.h>



class SensorfwCompass : public SensorfwSensorBase
{
    Q_OBJECT

public:
    static char const * const id;
    SensorfwCompass(QSensor *sensor);
protected:
    virtual bool doConnect();
    virtual QString sensorName() const;
    virtual void init() Q_DECL_OVERRIDE;
private:
    QCompassReading m_reading;
    bool m_initDone;
private slots:
    void slotDataAvailable(const Compass& data);
};

#endif

==> qt-everywhere-opensource-src-5.3.2.tar.xz: qt-everywhere-opensource-src-5.3.2/qtsensors/src/plugins/sensors/sensorfw/sensorfwcompass.h <==
/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtSensors module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef SENSORFWCOMPASS_H
#define SENSORFWCOMPASS_H

#include "sensorfwsensorbase.h"
#include <QtSensors/qcompass.h>

#include <compasssensor_i.h>
#include <datatypes/compass.h>



class SensorfwCompass : public SensorfwSensorBase
{
    Q_OBJECT

public:
    static char const * const id;
    SensorfwCompass(QSensor *sensor);
protected:
    bool doConnect() Q_DECL_OVERRIDE;
    QString sensorName() const Q_DECL_OVERRIDE;
    void start() Q_DECL_OVERRIDE;
    virtual void init();
private:
    QCompassReading m_reading;
    bool m_initDone;
private slots:
    void slotDataAvailable(const Compass& data);
};

#endif
